<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/organiseur?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_enregistrer_brouillon' => 'Entwurf speichern',
	'bouton_envoyer_message' => 'Senden',
	'bouton_envoyer_message_maintenant' => 'Jetzt senden',

	// C
	'cal_jour_entier' => 'ganztägig',
	'cal_par_jour' => 'Tag',
	'cal_par_mois' => 'Monat',
	'cal_par_semaine' => 'Woche',

	// E
	'erreur_date' => 'Falsches Datum',
	'erreur_date_avant_apres' => 'Geben Sie bitte ein Enddatum an, das nach dem Beginn liegt.',
	'erreur_date_corrigee' => 'Datum wurde geändert',
	'erreur_destinataire_invalide' => 'Der Empfänger @dest@ ist ungültig',
	'erreur_heure' => 'Falsche Uhrzeit (Stunde)',
	'erreur_heure_corrigee' => 'Uhrzeit wurde geändert',

	// I
	'icone_ecrire_nouveau_message' => 'Nachricht senden',
	'icone_ecrire_nouveau_pensebete' => 'Neue Notiz schreiben',
	'icone_ecrire_nouvelle_annonce' => 'Neue Ankündigung veröffentlichen',
	'icone_effacer_message' => 'Nachricht löschen',
	'icone_modifier_annonce' => 'Ankündigung bearbeiten',
	'icone_modifier_message' => 'Diese Nachricht bearbeiten',
	'icone_modifier_pensebete' => 'Notiz ändern',
	'icone_supprimer_message' => 'Nachricht löschen',
	'info_1_message_envoye' => '1 Nachricht gesendet',
	'info_1_message_nonlu' => '1 neue Nachricht',
	'info_agenda_interne' => 'Interner Kalender',
	'info_message_a' => 'An',
	'info_message_date' => 'Datum',
	'info_message_date_debut' => 'Anfangsdatum',
	'info_message_date_fin' => 'Enddatum',
	'info_message_de' => 'Von',
	'info_message_non_lu' => 'Neue Nachricht',
	'info_message_objet' => 'Gegenstand',
	'info_nb_messages_envoyes' => '@nb@ Nachrichten gesendet',
	'info_nb_messages_nonlus' => '@nb@ neue Nachrichten',
	'info_selection_annonces' => 'Ankündigungen',
	'info_selection_messages' => 'Nachrichten',
	'info_selection_pensebetes' => 'Notizen',
	'info_type_message_affich' => 'Ankündigung',
	'info_type_message_normal' => 'Nachricht',
	'info_type_message_pb' => 'Notiz',
	'info_type_message_rv' => 'Verabredung',

	// L
	'label_destinataires' => 'An',
	'label_texte' => 'Text',
	'label_titre' => 'Thema',
	'loading' => 'lade ...',

	// M
	'message' => 'Nachricht',
	'messages' => 'Nachrichten',

	// N
	'notification_annonce_lire_a_ladresse' => 'Hier zu lesen: @url@.',
	'notification_annonce_publie_1' => '[@nom_site_spip@] allgemeine Ankündigung',
	'notification_message_lire_a_ladresse' => 'Hier lesen und beantworten @url@.',
	'notification_message_publie_1' => '[@nom_site_spip@] neue Nachricht',
	'notification_message_recu_de' => 'Sie haben eine neue Nachricht von @nom@.',

	// T
	'texte_message_brouillon' => 'Diese Nachricht wurde als Entwurf gespeichert',
	'titre_agenda_rv' => 'Verabredung',
	'titre_boite_envoi' => 'Postausgang',
	'titre_boite_reception' => 'Posteingang'
);

?>
